exceptiontools.TempoError
=========================

.. abjad-lineage:: abjad.tools.exceptiontools.TempoError.TempoError

.. autoclass:: abjad.tools.exceptiontools.TempoError.TempoError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TempoError.TempoError.__unicode__
   :noindex:
